@@ -64,7 +64,7 @@ pub fn generate_closure_template(
 
         let future = async move {
             future_inner.await.ok();
-            context.finishe_task(None).await;
+            context.finish_task(None).await;
         };
 
         create_delay_task_handler(async_spawn_by_tokio(future))
